<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>TreeWindow</name>
    <message>
        <location filename="../../../treewindow.ui" line="14"/>
        <source>Panel DOM tree</source>
        <translation>パネルのDOMツリー</translation>
    </message>
    <message>
        <location filename="../../../treewindow.ui" line="63"/>
        <location filename="../../../treewindow.ui" line="96"/>
        <source>Property</source>
        <translation>プロパティー</translation>
    </message>
    <message>
        <location filename="../../../treewindow.ui" line="68"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
    <message>
        <location filename="../../../treewindow.ui" line="76"/>
        <source>All properties</source>
        <translation>全てのプロパティ</translation>
    </message>
    <message>
        <location filename="../../../treewindow.ui" line="101"/>
        <source>Type</source>
        <translation>タイプ</translation>
    </message>
    <message>
        <location filename="../../../treewindow.ui" line="106"/>
        <source>String value</source>
        <translation>値</translation>
    </message>
</context>
</TS>
